@@ -13,4 +13,5 @@ click_de_mouse = dispatch.Signal(providing_args=['button', 'x', 'y'])
 termina_click = dispatch.Signal(providing_args=['button', 'x', 'y'])
 mueve_rueda = dispatch.Signal(providing_args=['delta'])
 pulsa_tecla = dispatch.Signal(providing_args=['code'])
-actualizar = dispatch.Signal(providing_args=['input'])
+pulsa_tecla_escape = dispatch.Signal(providing_args=[])
+actualizar = dispatch.Signal(providing_args=[])
